@@ -24,17 +24,16 @@ class Formatter(logging.Formatter):
         return converted.strftime(datefmt) if datefmt else converted.isoformat()
 
     def __init__(
-        self,
-        fmt="%(asctime)s :: %(levelname)-10s :: %(message)s",
-        datefmt=None,
-        timezone="UTC",
+            self,
+            fmt="%(asctime)s :: %(levelname)-10s :: %(message)s",
+            datefmt=None,
+            timezone="UTC",
     ):
         super().__init__(fmt=fmt, datefmt=datefmt)
         self.tzName = timezone
 
 
 class Logger(logging.Logger):
-
     FORMATTER = Formatter(timezone=g.timezone)
     STREAM_LOG_LEVEL = logging.DEBUG
     FILE_LOG_LEVEL = logging.DEBUG
@@ -62,13 +61,13 @@ class Logger(logging.Logger):
         return streamHandler
 
     def addFileHandler(
-        self,
-        level=FILE_LOG_LEVEL,
-        formatter=FORMATTER,
-        logPath=LOG_PATH,
-        logFile=LOG_FILE,
-        logFileMaxSize=LOG_FILE_MAX_SIZE,
-        backupCount=BACKUP_COUNT,
+            self,
+            level=FILE_LOG_LEVEL,
+            formatter=FORMATTER,
+            logPath=LOG_PATH,
+            logFile=LOG_FILE,
+            logFileMaxSize=LOG_FILE_MAX_SIZE,
+            backupCount=BACKUP_COUNT,
     ):
         logFile = logFile or f"{self.name}.log"
         logFilePath = os.path.join(logPath, logFile)
@@ -82,13 +81,13 @@ class Logger(logging.Logger):
         return fileHandler
 
     def addLogkitHandler(
-        self,
-        level=LOGKIT_LOG_LEVEL,
-        formatter=FORMATTER,
-        uri=LOGKIT_URI,
-        namespace=LOGKIT_NAMESPACE,
-        socketio_path=LOGKIT_PATH,
-        event=LOGKIT_EVENTS_APPEND,
+            self,
+            level=LOGKIT_LOG_LEVEL,
+            formatter=FORMATTER,
+            uri=LOGKIT_URI,
+            namespace=LOGKIT_NAMESPACE,
+            socketio_path=LOGKIT_PATH,
+            event=LOGKIT_EVENTS_APPEND,
     ):
         url = urljoin(uri, namespace)
         logkitHandler = LoggerLogkitHandler(url, namespace, socketio_path, event)
@@ -111,17 +110,17 @@ class Logger(logging.Logger):
         self.debug("Python (ver: {})".format(platform.python_version()))
 
     def makeRecord(
-        self,
-        name,
-        level,
-        fn,
-        lno,
-        msg,
-        args,
-        exc_info,
-        func=None,
-        extra=None,
-        sinfo=None,
+            self,
+            name,
+            level,
+            fn,
+            lno,
+            msg,
+            args,
+            exc_info,
+            func=None,
+            extra=None,
+            sinfo=None,
     ):
         extra = {"extra": {"app": g.appId, "node": g.nodeId, **(extra or {})}}
         return super().makeRecord(
@@ -164,18 +163,14 @@ class LoggerLogkitHandler(logging.Handler):
 
     def makePickle(self, record):
         app = record.extra.pop("app")
-        json = {
-            "app": app,
-            "logs": [
+        data = (app,
                 {
                     "level": record.levelname,
                     "title": record.message,
                     "data": record.extra,
                     "time": datetime.datetime.now().isoformat(),
-                }
-            ],
-        }
-        return json
+                })
+        return data
 
     def emit(self, record):
         try:
